==> xlniuxdata-vipgame-1.0.65-20170103.065824-54-sources.jar: com/xunlei/niux/data/vipgame/vo/customerService/CsCaller.java <==
package com.xunlei.niux.data.vipgame.vo.customerService;

import com.ferret.common.dao.annotation.Table;

/**
 * Created by zhangya on 2016/12/20.
 */
@Table(tableName = "cs_caller", pkFieldName = "seqid", pkFieldAssign = false)
public class CsCaller {

    private Long seqid;
    private Long demandId;
    private Long userId;
    private String phone;
    private Integer answer;
    private Integer accept;
    private String lastCallTime;
    private String feedback;
    private String editTime;
    private String editBy;
    private Integer status;
    private Integer orderNo;


    public Integer getOrderNo() {
        return orderNo;
    }

    public void setOrderNo(Integer orderNo) {
        this.orderNo = orderNo;
    }

    public String getLastCallTime() {
        return lastCallTime;
    }

    public void setLastCallTime(String lastCallTime) {
        this.lastCallTime = lastCallTime;
    }

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }

    public Long getSeqid() {
        return seqid;
    }

    public void setSeqid(Long seqid) {
        this.seqid = seqid;
    }

    public Long getDemandId() {
        return demandId;
    }

    public void setDemandId(Long demandId) {
        this.demandId = demandId;
    }

    public Integer getAnswer() {
        return answer;
    }

    public void setAnswer(Integer answer) {
        this.answer = answer;
    }

    public Integer getAccept() {
        return accept;
    }

    public void setAccept(Integer accept) {
        this.accept = accept;
    }

    public String getFeedback() {
        return feedback;
    }

    public void setFeedback(String feedback) {
        this.feedback = feedback;
    }

    public String getEditTime() {
        return editTime;
    }

    public void setEditTime(String editTime) {
        this.editTime = editTime;
    }

    public String getEditBy() {
        return editBy;
    }

    public void setEditBy(String editBy) {
        this.editBy = editBy;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }
}

==> xlniuxdata-vipgame-1.1.2-20190423.093155-5-sources.jar: com/xunlei/niux/data/vipgame/vo/customerService/CsCaller.java <==
package com.xunlei.niux.data.vipgame.vo.customerService;

import com.ferret.common.dao.annotation.Table;

/**
 * Created by zhangya on 2016/12/20.
 */
@Table(tableName = "cs_caller", pkFieldName = "seqid", pkFieldAssign = false)
public class CsCaller {

    private Long seqid;
    private Long demandId;
    private Long userId;
    private String phone;
    private Integer answer;
    private Integer accept;
    private String lastCallTime;
    private String feedback;
    private String editTime;
    private String editBy;
    private Integer status;
    private Integer orderNo;

    private String userName;
    private Integer feedbackType;


    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }

    public Integer getFeedbackType() {
        return feedbackType;
    }

    public void setFeedbackType(Integer feedbackType) {
        this.feedbackType = feedbackType;
    }

    public Integer getOrderNo() {
        return orderNo;
    }

    public void setOrderNo(Integer orderNo) {
        this.orderNo = orderNo;
    }

    public String getLastCallTime() {
        return lastCallTime;
    }

    public void setLastCallTime(String lastCallTime) {
        this.lastCallTime = lastCallTime;
    }

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }

    public Long getSeqid() {
        return seqid;
    }

    public void setSeqid(Long seqid) {
        this.seqid = seqid;
    }

    public Long getDemandId() {
        return demandId;
    }

    public void setDemandId(Long demandId) {
        this.demandId = demandId;
    }

    public Integer getAnswer() {
        return answer;
    }

    public void setAnswer(Integer answer) {
        this.answer = answer;
    }

    public Integer getAccept() {
        return accept;
    }

    public void setAccept(Integer accept) {
        this.accept = accept;
    }

    public String getFeedback() {
        return feedback;
    }

    public void setFeedback(String feedback) {
        this.feedback = feedback;
    }

    public String getEditTime() {
        return editTime;
    }

    public void setEditTime(String editTime) {
        this.editTime = editTime;
    }

    public String getEditBy() {
        return editBy;
    }

    public void setEditBy(String editBy) {
        this.editBy = editBy;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }
}
